@defaults = ( [  2, 2 ], 1, 1, 7, 0.01, 0.99 );



### The above line means: ( [ resolution_x, resolution_y ], $dirvectorsnum, $bounceambnum, $bouncemaxnum, $distgrid, $threshold )

### resolution_x, resolution_y are the gridding values

### The value "$dirvectorsnum" controls the numbers of direction vectors that are used for 
### computing the irradiances at each point of each grid over the surfaces. The values that currently
### can be chosen are 1, 5 and 9. When the points are more than 1, they are evenly distributed 
### on a hemisphere following a geodetic pattern.

### $bounceambnum are the number of the bounces of the diffuse light which are taken into account

# $bouncemaxnum are the number of the bounces of the direct light which are taken into account

# $distgrid is the distance of the grid in meter out of the surfaces which are tamen into account

# $threshold is the threshold under which the changes of shading value are not taken into account. 
# A value of "1" means that if the new shading value is increased instead of decreased in place of the old one,
# the change is not executed.

$computype = "linear";
# TYPES OF CALCULATIONS FOR CALCULATING THE IRRADIANCE FACTORS.
# (SEE SUBROUTINE "compareirrs".)
# OPTIONS: "linear", "quadratic", "root".
# THESE OPTIONS ARE ON THE WAY TO BE DISCARDED AND BECOME OBSOLETE.
# WHEN ABSENT, THEY DEFAULT TO "linear".

$calcprocedure = "complete";
# THESE CALCULATION OPTIONS REGARD THE IRRADIANCES. THEY ARE: "complete" AND "simplified".
# (SEE SUBROUTINE "pursue").
# WITH THE "complete" option, both $bounceambnum and $bouncemaxnum must be assigned a value higher than 0.
# WHEN ABSENT, THEY DEFAULT TO "SIMPLIFIED".


